@@ -1,6 +1,6 @@
 /*
  *  git2r, R bindings to the libgit2 library.
- *  Copyright (C) 2013-2018 The git2r contributors
+ *  Copyright (C) 2013-2024 The git2r contributors
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -16,6 +16,7 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <R_ext/Visibility.h>
 #include <git2.h>
 
 #include "git2r_arg.h"
@@ -33,7 +34,9 @@
  * @param repository The repository
  * @return 0 if ok, else error code.
  */
-static int git2r_any_changes_in_index(git_repository *repository)
+static int
+git2r_any_changes_in_index(
+    git_repository *repository)
 {
     int error;
     int changes_in_index = 0;
@@ -69,7 +72,7 @@ static int git2r_any_changes_in_index(git_repository *repository)
     }
 
     if (!changes_in_index) {
-        giterr_set_str(GITERR_NONE, git2r_err_nothing_added_to_commit);
+        giterr_set_str(GIT_ERROR_NONE, git2r_err_nothing_added_to_commit);
         error = GIT_ERROR;
     }
 
@@ -85,7 +88,10 @@ cleanup:
  * @param n_parents The number of parents.
  * @return void
  */
-static void git2r_parents_free(git_commit **parents, size_t n_parents)
+static void
+git2r_parents_free(
+    git_commit **parents,
+    size_t n_parents)
 {
     if (parents) {
         size_t i;
@@ -116,7 +122,8 @@ typedef struct {
  * @param payload Payload data passed to 'git_repository_mergehead_foreach'
  * @return 0
  */
-static int git2r_repository_mergehead_foreach_cb(
+static int
+git2r_repository_mergehead_foreach_cb(
     const git_oid *oid,
     void *payload)
 {
@@ -142,7 +149,8 @@ static int git2r_repository_mergehead_foreach_cb(
  * @param repository The repository
  * @return 0 on succes, or error code
  */
-static int git2r_retrieve_parents(
+static int
+git2r_retrieve_parents(
     git_commit ***parents,
     size_t *n_parents,
     git_repository *repository)
@@ -173,7 +181,7 @@ static int git2r_retrieve_parents(
 
     *parents = calloc(cb_data.n + 1, sizeof(git_commit*));
     if (!parents) {
-        giterr_set_str(GITERR_NONE, git2r_err_alloc_memory_buffer);
+        giterr_set_str(GIT_ERROR_NONE, git2r_err_alloc_memory_buffer);
         return GIT_ERROR;
     }
     *n_parents = cb_data.n + 1;
@@ -213,7 +221,8 @@ static int git2r_retrieve_parents(
  * @param committer Who is the committer
  * @return 0 on success, or error code
  */
-int git2r_commit_create(
+int attribute_hidden
+git2r_commit_create(
     git_oid *out,
     git_repository *repository,
     git_index *index,
@@ -249,7 +258,13 @@ int git2r_commit_create(
         message,
         tree,
         n_parents,
+#if LIBGIT2_VER_MAJOR == 1 && \
+    LIBGIT2_VER_MINOR == 8 && \
+    (LIBGIT2_VER_REVISION == 0 || LIBGIT2_VER_REVISION == 1)
+        (git_commit*const*)parents);
+#else
         (const git_commit**)parents);
+#endif
     if (error)
         goto cleanup;
 
@@ -270,7 +285,8 @@ cleanup:
  * @param committer S3 class git_signature
  * @return S3 class git_commit
  */
-SEXP git2r_commit(
+SEXP attribute_hidden
+git2r_commit(
     SEXP repo,
     SEXP message,
     SEXP author,
@@ -343,7 +359,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, giterr_last(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -356,7 +372,8 @@ cleanup:
  * @param commit S3 class git_commit
  * @return 0 or an error code
  */
-int git2r_commit_lookup(
+int attribute_hidden
+git2r_commit_lookup(
     git_commit **out,
     git_repository *repository,
     SEXP commit)
@@ -375,7 +392,9 @@ int git2r_commit_lookup(
  * @param commit S3 class git_commit or git_stash
  * @return S3 class git_tree
  */
-SEXP git2r_commit_tree(SEXP commit)
+SEXP attribute_hidden
+git2r_commit_tree(
+    SEXP commit)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -415,7 +434,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, giterr_last(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return result;
 }
@@ -428,7 +447,11 @@ cleanup:
  * @param dest S3 class git_commit to initialize
  * @return void
  */
-void git2r_commit_init(git_commit *source, SEXP repo, SEXP dest)
+void attribute_hidden
+git2r_commit_init(
+    git_commit *source,
+    SEXP repo,
+    SEXP dest)
 {
     const char *str;
     const git_signature *signature;
@@ -487,7 +510,9 @@ void git2r_commit_init(git_commit *source, SEXP repo, SEXP dest)
  * @param commit S3 class git_commit
  * @return list of S3 class git_commit objects
  */
-SEXP git2r_commit_parent_list(SEXP commit)
+SEXP attribute_hidden
+git2r_commit_parent_list(
+    SEXP commit)
 {
     int error, nprotect = 0;
     size_t i, n;
@@ -538,7 +563,7 @@ cleanup:
         UNPROTECT(nprotect);
 
     if (error)
-        git2r_error(__func__, giterr_last(), NULL, NULL);
+        git2r_error(__func__, git_error_last(), NULL, NULL);
 
     return list;
 }
