@@ -22,6 +22,7 @@
 #include "git2r_arg.h"
 #include "git2r_cred.h"
 #include "git2r_error.h"
+#include "git2r_proxy.h"
 #include "git2r_remote.h"
 #include "git2r_repository.h"
 #include "git2r_S3.h"
@@ -123,6 +124,7 @@ git2r_update_tips_cb(
  * @param verbose Print information each time a reference is updated locally.
  * @param refspecs The refspecs to use for this fetch. Pass R_NilValue
  *        to use the base refspecs.
+ * @param proxy_val The proxy settings
  * @return R_NilValue
  */
 SEXP attribute_hidden
@@ -132,7 +134,8 @@ git2r_remote_fetch(
     SEXP credentials,
     SEXP msg,
     SEXP verbose,
-    SEXP refspecs)
+    SEXP refspecs,
+    SEXP proxy_val)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -142,6 +145,7 @@ git2r_remote_fetch(
     git_fetch_options fetch_opts = GIT_FETCH_OPTIONS_INIT;
     git2r_transfer_data payload = GIT2R_TRANSFER_DATA_INIT;
     git_strarray refs = {0};
+    git_proxy_options proxy_opts = GIT_PROXY_OPTIONS_INIT;
 
     if (git2r_arg_check_string(name))
         git2r_error(__func__, NULL, "'name'", git2r_err_string_arg);
@@ -153,6 +157,19 @@ git2r_remote_fetch(
         git2r_error(__func__, NULL, "'verbose'", git2r_err_logical_arg);
     if ((!Rf_isNull(refspecs)) && git2r_arg_check_string_vec(refspecs))
         git2r_error(__func__, NULL, "'refspecs'", git2r_err_string_vec_arg);
+    if (git2r_arg_check_proxy(proxy_val))
+        git2r_error(__func__, NULL, "'proxy_val'", git2r_err_proxy_arg);
+
+    /* Initialize proxy options */
+    error = git2r_set_proxy_options(&proxy_opts, proxy_val);
+    if (error)
+        git2r_error(
+            __func__,
+            git_error_last(),
+            git2r_err_unable_to_set_proxy_options,
+            NULL);
+    
+    fetch_opts.proxy_opts = proxy_opts;
 
     repository = git2r_repository_open(repo);
     if (!repository)
@@ -452,13 +469,17 @@ cleanup:
  * Based on https://github.com/libgit2/libgit2/blob/babdc376c7/examples/network/ls-remote.c
  * @param repo S3 class git_repository
  * @param name Character vector with URL of remote.
+ * @param credentials The credentials for remote repository access.
+ * @param proxy_val The proxy settings for the remote (NULL, TRUE, or a string with proxy URL).
  * @return Character vector for each reference with the associated commit IDs.
  */
 SEXP attribute_hidden
 git2r_remote_ls(
     SEXP name,
     SEXP repo,
-    SEXP credentials)
+    SEXP credentials,
+    SEXP proxy_val
+)
 {
     const char *name_ = NULL;
     SEXP result = R_NilValue;
@@ -470,11 +491,14 @@ git2r_remote_ls(
     git_remote_callbacks callbacks = GIT_REMOTE_CALLBACKS_INIT;
     git2r_transfer_data payload = GIT2R_TRANSFER_DATA_INIT;
     git_repository *repository = NULL;
+    git_proxy_options proxy_opts;
 
     if (git2r_arg_check_string(name))
         git2r_error(__func__, NULL, "'name'", git2r_err_string_arg);
     if (git2r_arg_check_credentials(credentials))
         git2r_error(__func__, NULL, "'credentials'", git2r_err_credentials_arg);
+    if (git2r_arg_check_proxy(proxy_val))
+        git2r_error(__func__, NULL, "'proxy_val'", git2r_err_proxy_arg);
 
     if (!Rf_isNull(repo)) {
         repository = git2r_repository_open(repo);
@@ -501,7 +525,11 @@ git2r_remote_ls(
     callbacks.payload = &payload;
     callbacks.credentials = &git2r_cred_acquire_cb;
 
-    error = git_remote_connect(remote, GIT_DIRECTION_FETCH, &callbacks, NULL, NULL);
+    error = git2r_set_proxy_options(&proxy_opts, proxy_val);
+    if (error)
+        goto cleanup;
+
+    error = git_remote_connect(remote, GIT_DIRECTION_FETCH, &callbacks, &proxy_opts, NULL);
     if (error)
         goto cleanup;
 
